@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 import os.path
@@ -18,6 +7,7 @@ import os.path
 from rez.build_process import BuildType
 from rez.exceptions import BuildSystemError
 from rez.packages import get_developer_package
+from rez.rex_bindings import VariantBinding
 
 
 def get_buildsys_types():
@@ -245,10 +235,9 @@ class BuildSystem(object):
         raise NotImplementedError
 
     @classmethod
-    def get_standard_vars(cls, context, variant, build_type, install,
+    def set_standard_vars(cls, executor, context, variant, build_type, install,
                           build_path, install_path=None):
-        """Returns a standard set of environment variables that can be set
-        for the build system to use
+        """Set some standard env vars that all build systems can rely on.
         """
         from rez.config import config
 
@@ -262,16 +251,18 @@ class BuildSystem(object):
 
         vars_ = {
             'REZ_BUILD_ENV': 1,
-            'REZ_BUILD_PATH': build_path,
+            'REZ_BUILD_PATH': executor.normalize_path(build_path),
             'REZ_BUILD_THREAD_COUNT': package.config.build_thread_count,
             'REZ_BUILD_VARIANT_INDEX': variant.index or 0,
             'REZ_BUILD_VARIANT_REQUIRES': ' '.join(variant_requires),
-            'REZ_BUILD_VARIANT_SUBPATH': variant_subpath,
+            'REZ_BUILD_VARIANT_SUBPATH': executor.normalize_path(variant_subpath),
             'REZ_BUILD_PROJECT_VERSION': str(package.version),
             'REZ_BUILD_PROJECT_NAME': package.name,
             'REZ_BUILD_PROJECT_DESCRIPTION': (package.description or '').strip(),
             'REZ_BUILD_PROJECT_FILE': package.filepath,
-            'REZ_BUILD_SOURCE_PATH': os.path.dirname(package.filepath),
+            'REZ_BUILD_SOURCE_PATH': executor.normalize_path(
+                os.path.dirname(package.filepath)
+            ),
             'REZ_BUILD_REQUIRES': ' '.join(
                 str(x) for x in context.requested_packages(True)
             ),
@@ -283,14 +274,16 @@ class BuildSystem(object):
         }
 
         if install_path:
-            vars_['REZ_BUILD_INSTALL_PATH'] = install_path
+            vars_['REZ_BUILD_INSTALL_PATH'] = executor.normalize_path(install_path)
 
         if config.rez_1_environment_variables and \
                 not config.disable_rez_1_compatibility and \
                 build_type == BuildType.central:
             vars_['REZ_IN_REZ_RELEASE'] = 1
 
-        return vars_
+        # set env vars
+        for key, value in vars_.items():
+            executor.env[key] = value
 
     @classmethod
     def add_pre_build_commands(cls, executor, variant, build_type, install,
@@ -303,16 +296,29 @@ class BuildSystem(object):
         build_ns = {
             "build_type": build_type.name,
             "install": install,
-            "build_path": build_path,
-            "install_path": install_path
+            "build_path": executor.normalize_path(build_path),
+            "install_path": executor.normalize_path(install_path)
         }
 
         # execute pre_build_commands()
+        # note that we need to wrap variant in a VariantBinding so that any refs
+        # to (eg) 'this.root' in pre_build_commands() will get the possibly
+        # normalized path.
+        #
         pre_build_commands = getattr(variant, "pre_build_commands")
 
+        # TODO I suspect variant root isn't correctly set to the cached root
+        # when pkg caching is enabled (see use of VariantBinding in
+        # ResolvedContext._execute).
+        #
+        bound_variant = VariantBinding(
+            variant,
+            interpreter=executor.interpreter
+        )
+
         if pre_build_commands:
             with executor.reset_globals():
-                executor.bind("this", variant)
+                executor.bind("this", bound_variant)
                 executor.bind("build", ROA(build_ns))
                 executor.execute_code(pre_build_commands)
 
@@ -322,7 +328,8 @@ class BuildSystem(object):
         """Perform build actions common to every build system.
         """
         # set env vars
-        env_vars = cls.get_standard_vars(
+        cls.set_standard_vars(
+            executor=executor,
             context=context,
             variant=variant,
             build_type=build_type,
@@ -330,6 +337,3 @@ class BuildSystem(object):
             build_path=build_path,
             install_path=install_path
         )
-
-        for var, value in env_vars.items():
-            executor.env[var] = value
