@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
@@ -535,6 +524,15 @@ env_var_separators = {
     "DOXYGEN_TAGFILES": " ",
 }
 
+# This setting identifies path-like environment variables. This is required
+# because some shells need to apply path normalization. For example, the command
+# `env.PATH.append("{root}/bin")` will be normalized to (eg) `C:\...\bin` in a
+# `cmd` shell on Windows. Note that wildcards are supported. If this setting is
+# not correctly configured, then your shell may not work correctly.
+pathed_env_vars = [
+    "*PATH"
+]
+
 # Defines what suites on $PATH stay visible when a new rez environment is resolved.
 # Possible values are:
 # - "never":            Don"t attempt to keep any suites visible in a new env
